Learn R Programming

ranlip (version 1.0.1)

ranlip.Seed: Function of setting the seed

Description

Function for setting the seed of the default uniform random number generator ranlux.

Usage

ranlip.Seed(seed)

Arguments

seed

Integer value to seed the random generator

Value

output

No return value, called to set the seed of the random generator.

Examples

Run this code
# NOT RUN {
	ranlip.Seed(17);
# }

Run the code above in your browser using DataLab